
源码来自于[PeterDing/BaiduPCS-Py](https://github.com/PeterDing/BaiduPCS-Py)

主要是去除了一些界面代码，服务代码，减少相关依赖，只提供代码API

具体使用方式参考[fundrive](https://github.com/farfarfun/fundrive/tree/master/src/fundrive/drives/baidu)